# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.0] - 2025-06-06

### Added

- Support for `Literal` and `list`
- Loading config from toml now checks types before setting
- Generating skeleton now works with subsections

### Fixed

- Fixed how config annotations are accessed, so that it works with PEP-749 in Python 3.14

## [0.1.0] - 2025-05-27

### Added

- First version of yaucl
